unit Main;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes,
  System.Variants, System.StrUtils,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.StdCtrls,
  FMX.ListBox, FMX.Layouts, FMX.Objects, FireDAC.Stan.Intf, FireDAC.Stan.Option,
  FireDAC.Stan.Param, FireDAC.Stan.Error, FireDAC.DatS, FireDAC.Phys.Intf,
  FireDAC.DApt.Intf,
  FireDAC.Stan.Async, FireDAC.DApt, FireDAC.UI.Intf, FireDAC.Stan.Def,
  FireDAC.Stan.Pool,
  FireDAC.Phys, FireDAC.Comp.Client, FireDAC.Comp.DataSet,
  FireDAC.Stan.ExprFuncs,
  FireDAC.FMXUI.Wait, FireDAC.Comp.UI, FireDAC.Phys.SQLite, Data.DB,
  System.IOUtils, Xml.xmldom,
  Xml.XMLIntf, Xml.adomxmldom, Xml.XMLDoc, FMX.Platform.Android, FMX.Memo,
  FireDAC.Phys.SQLiteDef, FMX.Controls.Presentation, UObjemULT, Math;

type

  TForm2 = class(TForm)
    ComboBox1: TComboBox;
    ComboBox2: TComboBox;
    ComboBox3: TComboBox;
    ComboBox4: TComboBox;
    ListBox1: TListBox;
    ComboBox5: TComboBox;
    ListBoxItem1: TListBoxItem;
    ListBoxItem2: TListBoxItem;
    ListBoxItem3: TListBoxItem;
    ListBoxItem4: TListBoxItem;
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    ListBoxHeader1: TListBoxHeader;
    Label1: TLabel;
    DBConnection: TFDConnection;
    SQLQuery: TFDQuery;
    Label2: TLabel;
    Button4: TButton;
    AniIndicator1: TAniIndicator;
    Line2: TLine;
    SQLQuery2: TFDQuery;
    SQLQuery3: TFDQuery;
    SQLQuery4: TFDQuery;

    procedure Button1Click(Sender: TObject);
    procedure ListBox1ItemClick(const Sender: TCustomListBox;
      const AItem: TListBoxItem);
    procedure LoadLHC(DataPath: String);
    procedure FormCreate(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure OnSelectDir(const S: string);
    procedure Button4Click(Sender: TObject);
    procedure ComboBox1Change(Sender: TObject);
    procedure ComboBox2Change(Sender: TObject);
    procedure ComboBox3Change(Sender: TObject);
    // procedure ComboBox4Change(Sender: TObject);

  private
    DBPath, firstODD, firstDIL, firstPOR, firstPS: String;
    rozmery: boolean;
    procedure LoadODD;
    procedure LoadDIL(oddeleni: String);
    procedure LoadPOR(dilec: String);
    procedure LoadPS(porost: String);
    // procedure LoadEtaz(skupina: String);
    function CloneRect(source: TRectangle; posunX: Integer; posunY: Integer;
      jmeno: String): TRectangle;
    function CloneLabel(source: TLabel; posunX: Integer; posunY: Integer;
      jmeno: String): TLabel;


  public
    HS: Integer;
    procedure zobrazHK(LHC, rok, oddeleni, dilec, porost, skupina: String);

  end;

var
  Form2: TForm2;


implementation

uses
  HK, t_xFileDialog;


{$R *.fmx}

// zobrazeni vyberu slozky
procedure TForm2.Button1Click(Sender: TObject);
begin

  XFileDialog.Directory := '/';
  XFileDialog.ed_Caption.Text := 'Vbr sloky s daty';
  XFileDialog.OnSelect := OnSelectDir;
  XFileDialog.DirsOnly := true;
  XFileDialog.Show;

end;

// vyber adresare s daty
procedure TForm2.OnSelectDir(const S: string);
var
  HomePath: String;
  FileStream: TFileStream;
  RootNode, CurNode: IXMLNODE;
  XMLDocument: IXMLDocument;
begin

  DBPath := S;
  HomePath := TPath.GetHomePath + '/miniHeletaxConf.xml';
  // Label2.Text := HomePath;
  // pokud neexistuje config soubor, vytvorime
  if not TFile.Exists(HomePath) then
  begin
    // TFile.Create(HomePath);
    // XMLDocument.Create(HomePath);
    XMLDocument := NewXMLDocument;
    XMLDocument.Active := true;
    XMLDocument.Encoding := 'utf-8';
    XMLDocument.Options := [doNodeAutoIndent];
    RootNode := XMLDocument.AddChild('root');
    CurNode := RootNode.AddChild('DBPath');
    CurNode.Text := DBPath;
    XMLDocument.SaveToFile(HomePath);
    XMLDocument.Active := false;
  end
  // jinak nacteme
  else
  begin
    XMLDocument := LoadXMLDocument(HomePath);
    XMLDocument.Active := true;
    RootNode := XMLDocument.DocumentElement;
    CurNode := RootNode.ChildNodes['DBPath'];
    CurNode.Text := DBPath;
    XMLDocument.SaveToFile(HomePath);
    XMLDocument.Active := false;
  end;
  Application.ProcessMessages;
  LoadLHC(DBPath);
end;

// datasnap pro zobrazeni HK
procedure TForm2.zobrazHK(LHC, rok, oddeleni, dilec, porost, skupina: String);
var
  oddeleniID, dilecID, porostID, skupinaID, etazID, pom, drevina, maj_kod,
    maj_druh: String;
  i, x, z, etazZast, radek, etazCount, pocetDrevin, formHeight, etazNO,
    radekNadpis, listJehl, navrhCount, navrhIndex: Integer;
  zasoba1, souse, zasobaC, TVP, TVO, TOP, TOO, prorezavkyP, zalProc, zalP,
    ps1ha, psCelkem: Double;
  rect: TRectangle;
  newLabel: TLabel;
  oH, layoutOrigHeight, layoutHeight: single;
  first, stejnaDrevina, drevinaMimo: boolean;
  drevinyNavrh, drevinyEtaz: array of String;
  Status, vek:integer;
begin

  // cesta k DB souboru
  DBConnection.Params.Values['Database'] := DBPath + '/LHC_' + LHC + '_' + rok
    + '.s3db';

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from oddeleni WHERE ODD = ' + oddeleni);
  SQLQuery.OpenOrExecute;
  oddeleniID := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from dilec WHERE DIL = "' + dilec +
    '" AND VAZBA = ' + oddeleniID);
  SQLQuery.OpenOrExecute;
  dilecID := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from porost WHERE POR = "' + porost +
    '" AND VAZBA = ' + dilecID);
  SQLQuery.OpenOrExecute;
  porostID := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from ps WHERE PSK = "' + skupina +
    '" AND VAZBA = ' + porostID);
  SQLQuery.OpenOrExecute;
  skupinaID := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  // reset - smazani vytvorenych obdelnicku a labelu z prechoziho zobrazeni HK
  for z := (HospKniha.ScaledLayout1.ChildrenCount - 1) downto 0 do
  begin
    pom := HospKniha.ScaledLayout1.Children.Items[z].Name;
    if pom.Contains('radekRect') then
    begin
      HospKniha.Height := HospKniha.Height - 33;
      HospKniha.ScaledLayout1.OriginalHeight :=
        HospKniha.ScaledLayout1.OriginalHeight - 33;
      HospKniha.ScaledLayout1.Height := HospKniha.ScaledLayout1.Height - 33;
    end;
    if pom.Contains('radek') then
    begin
      if HospKniha.ScaledLayout1.Children.Items[z].ChildrenCount > 0 then
      begin
        for x := (HospKniha.ScaledLayout1.Children.Items[z].ChildrenCount - 1)
          downto 0 do
        begin
          HospKniha.ScaledLayout1.Children.Items[z].Children.Items[x].DisposeOf;
        end;
      end;
      HospKniha.ScaledLayout1.Children.Items[z].DisposeOf;
    end;
  end;

  radek := 1;
  etazNO := 1;
  radekNadpis := 0;
  ps1ha := 0;
  psCelkem := 0;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT count(*) as c from etaz where Vazba = ' + skupinaID);
  SQLQuery.OpenOrExecute;
  etazCount := SQLQuery.FieldByName('c').AsInteger;
  SQLQuery.Close;

  // vyroba obdelnicku a labelu pro etaze

  newLabel := CloneLabel(HospKniha.Label93, 40, 0, 'etaz1nadpisVEKradek0');
  newLabel.Text := '';
  HospKniha.ScaledLayout1.AddObject(newLabel);
  newLabel := CloneLabel(HospKniha.Label93, 80, 0, 'etaz1nadpisZAKMradek0');
  newLabel.Text := '';
  HospKniha.ScaledLayout1.AddObject(newLabel);
  for z := 0 to 24 do
  begin
    newLabel := CloneLabel(HospKniha.Label93, 120 + 40 * z, 0,
      'etaz' + IntToStr(etazNO) + 'radek0s' + IntToStr(z));
    newLabel.Text := '';
    HospKniha.ScaledLayout1.AddObject(newLabel);
  end;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from etaz where Vazba = ' + skupinaID);
  SQLQuery.OpenOrExecute;
  while NOT SQLQuery.Eof do
  begin

    SQLQuery2.SQL.Clear;
    SQLQuery2.SQL.Add('SELECT count(*) as c from drevina where VAZBA = ' +
      SQLQuery.FieldByName('ID').AsString);
    SQLQuery2.OpenOrExecute;
    pocetDrevin := SQLQuery2.FieldByName('c').AsInteger;

    if etazNO = 1 then
    begin
    HospKniha.Label276.Position.Y := 376 + pocetDrevin * 32;
    end;
    // okenka s daty o etazi pro kazdou dalsi etaz po prvni
    if etazNO <> 1 then
    begin
      rect := CloneRect(HospKniha.Rectangle107, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis1radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle108, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis2radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle109, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis3radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle27, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis4radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle30, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis5radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle29, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis6radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle28, 0, 96 + 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpis7radek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);

      radekNadpis := radek;
      Inc(radek);

      rect := CloneRect(HospKniha.Rectangle73, 0, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisRectHSradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle74, 0, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisRectVEKradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      rect := CloneRect(HospKniha.Rectangle75, 0, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisRectZAKMradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);

      newLabel := CloneLabel(HospKniha.Label93, 0, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisHSradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      newLabel := CloneLabel(HospKniha.Label93, 40, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisVEKradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      newLabel := CloneLabel(HospKniha.Label93, 80, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'nadpisZAKMradek' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);

      newLabel := CloneLabel(HospKniha.Label93, 0, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's0001');
      newLabel.Text := '';
      HospKniha.ScaledLayout1.AddObject(newLabel);

      newLabel := CloneLabel(HospKniha.Label93, 40, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's001');
      newLabel.Text := '';
      HospKniha.ScaledLayout1.AddObject(newLabel);

      newLabel := CloneLabel(HospKniha.Label93, 80, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's01');
      newLabel.Text := '';
      HospKniha.ScaledLayout1.AddObject(newLabel);
      (*

        rect := CloneRect(HospKniha.Rectangle76, 0, 32 * radek,
        'radekCelkemOhr' + IntToStr(radek));
        rect.Height := rect.Height + 32*(pocetDrevin-1);
        HospKniha.ScaledLayout1.AddObject(rect);
      *)
    end;

    // radky etaze
    for i := 1 to (pocetDrevin + 1) do
    begin

      rect := CloneRect(HospKniha.Rectangle32, 0, 32 * radek,
        'radekRect' + IntToStr(radek));
      HospKniha.ScaledLayout1.AddObject(rect);
      HospKniha.Height := HospKniha.Height + 33;
      HospKniha.ScaledLayout1.OriginalHeight :=
        HospKniha.ScaledLayout1.OriginalHeight + 33;
      HospKniha.ScaledLayout1.Height := HospKniha.ScaledLayout1.Height + 33;

      for z := 0 to 24 do
      begin
        newLabel := CloneLabel(HospKniha.Label93, 120 + 40 * z, 32 * radek,
          'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
          IntToStr(z));
        newLabel.Text := '';
        HospKniha.ScaledLayout1.AddObject(newLabel);
      end;

      Inc(radek);

      if (etazNO <> 1) AND (radek - radekNadpis > 2) then
      begin
        rect := CloneRect(HospKniha.Rectangle32, 0, 32 * radek,
          'radekRect' + IntToStr(radek));
        HospKniha.ScaledLayout1.AddObject(rect);
        HospKniha.Height := HospKniha.Height + 33;
        HospKniha.ScaledLayout1.OriginalHeight :=
          HospKniha.ScaledLayout1.OriginalHeight + 33;
        HospKniha.ScaledLayout1.Height := HospKniha.ScaledLayout1.Height + 33;

        for z := 0 to 24 do
        begin
          newLabel := CloneLabel(HospKniha.Label93, 120 + 40 * z, 32 * radek,
            'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
            IntToStr(z));
          newLabel.Text := '';
          HospKniha.ScaledLayout1.AddObject(newLabel);
        end;
        if (i = pocetDrevin + 1) then
        begin
          newLabel := CloneLabel(HospKniha.etazLabel, 0, 32 * (radek - 1),
            'etazCelkem' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
            IntToStr(z));

          HospKniha.ScaledLayout1.AddObject(newLabel);
          // HospKniha.etazLabel.Visible := false;
        end;
        (* if (etazNO = 1) then

          begin
          newLabel := CloneLabel(HospKniha.etazLabel, 0, 32 * (radek - 1),
          'etazCelkem' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
          IntToStr(z));

          HospKniha.ScaledLayout1.AddObject(newLabel)
          end; *)

      end;

    end;

    (*
      for i := 1 to radek do
      begin
      for z := 0 to 24 do
      begin
      newLabel := CloneLabel(HospKniha.refLabel, 120 + 40 * z,
      32 * radek, 'etaz' + IntToStr(etazNO) + 'radek' +
      IntToStr(i) + 's' + IntToStr(z));
      newLabel.Text := newLabel.Name;
      HospKniha.ScaledLayout1.AddObject(newLabel);
      end;
      end;
    *)
    SQLQuery2.Close;
    if etazCount > 1 then
    begin
      Inc(etazNO);
    end;

    SQLQuery.Next;

  end;

  if etazNO <> 1 then
  begin
    Inc(radek);
  end;

  // posledni radek
  begin
    rect := CloneRect(HospKniha.Rectangle32, 0, 32 * radek,
      'radekRect' + IntToStr(radek));
    HospKniha.ScaledLayout1.AddObject(rect);
    HospKniha.Height := HospKniha.Height + 33;
    HospKniha.ScaledLayout1.OriginalHeight :=
      HospKniha.ScaledLayout1.OriginalHeight + 33;
    HospKniha.ScaledLayout1.Height := HospKniha.ScaledLayout1.Height + 33;

    for z := 0 to 24 do
    begin
      newLabel := CloneLabel(HospKniha.Label93, 120 + 40 * z, 32 * radek,
        'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
        IntToStr(z));
      newLabel.Text := '';
      HospKniha.ScaledLayout1.AddObject(newLabel);
    end;
    HospKniha.Label91.Position.Y := 408 + (radek - 2) * 32;
  end;


  // svisle obdelnicky
  HospKniha.Rectangle1.Height := 257 + (radek - 2) * 32;

  HospKniha.Rectangle100.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle101.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle102.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle103.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle104.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle105.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle106.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle76.Height := 65 + (radek - 2) * 32;
  HospKniha.Rectangle77.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle78.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle79.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle80.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle81.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle82.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle83.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle84.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle85.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle86.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle87.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle88.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle89.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle90.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle91.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle92.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle93.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle94.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle95.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle96.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle97.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle98.Height := 97 + (radek - 2) * 32;
  HospKniha.Rectangle99.Height := 97 + (radek - 2) * 32;

  SQLQuery.Close;

  // plneni dat
  HospKniha.Label8.Text := LHC;
  HospKniha.Label24.Text := oddeleni;
  HospKniha.Label26.Text := dilec;
  HospKniha.Label28.Text := porost;
  HospKniha.Label32.Text := skupina;
  // HospKniha.Label271.Text := etaz;

  // obecna data zavisla na oddeleni, dilci, porostu a skupine
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT Poznamka from ps_pozn WHERE Vazba = ' + skupinaID);
  SQLQuery.OpenOrExecute;
  if not SQLQuery.FieldByName('Poznamka').IsNull then
    HospKniha.Label48.Text := SQLQuery.FieldByName('Poznamka').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT POZNAMKA from por_pozn WHERE VAZBA = ' + porostID);
  SQLQuery.OpenOrExecute;
  if not SQLQuery.FieldByName('POZNAMKA').IsNull then
    HospKniha.Label30.Text := SQLQuery.FieldByName('POZNAMKA').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from lhc WHERE LHC_KOD = ' + LHC);
  SQLQuery.OpenOrExecute;
  HospKniha.Label11.Text := SQLQuery.FieldByName('LHP_OD').AsString + ' - ' +
    SQLQuery.FieldByName('LHP_DO').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from porost WHERE ID = ' + porostID);
  SQLQuery.OpenOrExecute;
  HospKniha.Label2.Text := SQLQuery.FieldByName('LES_OBL').AsString;
  HospKniha.Label6.Text := SQLQuery.FieldByName('ZVL_STATUS').AsString;
  HospKniha.Label10.Text := SQLQuery.FieldByName('PAS_OHR').AsString;
  HospKniha.Label4.Text := SQLQuery.FieldByName('KATEGORIE').AsString;
  HospKniha.Label14.Text := SQLQuery.FieldByName('ORG_UROVEN1').AsString;
  HospKniha.Label16.Text := SQLQuery.FieldByName('ORG_UROVEN2').AsString;
  HospKniha.Label18.Text := SQLQuery.FieldByName('ORG_UROVEN3').AsString;

  maj_kod := SQLQuery.FieldByName('MAJ_KOD').AsString;
  maj_druh := SQLQuery.FieldByName('MAJ_DRUH').AsString;

  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add
    ('SELECT ROUND(SUM(PSK_P),2) as suma FROM ps WHERE VAZBA IN (SELECT ID FROM porost WHERE VAZBA IN (SELECT ID FROM dilec WHERE VAZBA = '
    + oddeleniID + '))');
  SQLQuery.OpenOrExecute;
  HospKniha.Label20.Text := SQLQuery.FieldByName('suma').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ROUND(SUM(PSK_P),2) as suma  FROM ps WHERE VAZBA =  '
    + porostID);
  SQLQuery.OpenOrExecute;
  HospKniha.Label22.Text := SQLQuery.FieldByName('suma').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from ps WHERE ID = ' + skupinaID);
  SQLQuery.OpenOrExecute;
  HospKniha.Label36.Text := SQLQuery.FieldByName('LT').AsString;
  HospKniha.Label38.Text := SQLQuery.FieldByName('LVS').AsString;
  HospKniha.Label42.Text := SQLQuery.FieldByName('TER_TYP').AsString;
  HospKniha.Label44.Text := SQLQuery.FieldByName('Terenni_skupina').AsString;
  HospKniha.Label46.Text := SQLQuery.FieldByName('KU_KOD').AsString;
  HospKniha.Label40.Text := SQLQuery.FieldByName('LES_URAD').AsString;
  HospKniha.Label34.Text := SQLQuery.FieldByName('PSK_P').AsString;
  SQLQuery.Close;

  // plneni dat o etazich

  SQLQuery3.SQL.Clear;
  SQLQuery3.SQL.Add('SELECT * from etaz WHERE VAZBA = ' + skupinaID);
  SQLQuery3.OpenOrExecute;

  radek := 0;
  etazNO := 1;

  while NOT SQLQuery3.Eof do
  begin
    // data o etazi

    SQLQuery.SQL.Clear;
    SQLQuery.SQL.Add('SELECT * from etaz WHERE ID = ' + SQLQuery3.FieldByName
      ('ID').AsString);
    etazID := SQLQuery3.FieldByName('ID').AsString;
    SQLQuery.OpenOrExecute;
    vek := 0;
    if etazNO = 1 then
    begin
      HospKniha.Label54.Text := SQLQuery.FieldByName('OBMYTI').AsString + '/' +
        SQLQuery.FieldByName('OBN_DOBA').AsString;
      HS := SQLQuery.FieldByName('HS').AsInteger;
      //HospKniha.Label273.Text := SQLQuery.FieldByName('ETAZ_PP').AsString;
      HospKniha.Label275.Text := SQLQuery.FieldByName('ETAZ_PS').AsString;
      HospKniha.Label56.Text := SQLQuery.FieldByName('MZD').AsString;
      HospKniha.Label271.Text := SQLQuery.FieldByName('ETAZ').AsString;
      HospKniha.Label50.Text := maj_druh + '/' + maj_kod;
      HospKniha.Label52.Text := SQLQuery.FieldByName('PROC_HS').AsString;

    end
    else
    begin
      pom := HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis1radek' + IntToStr(radek)).Components[1].Name;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis1radek' + IntToStr(radek)).Components[1]).Text :=
        SQLQuery.FieldByName('ETAZ').AsString;
      //TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
       // 'nadpis2radek' + IntToStr(radek)).Components[1]).Text :=
       // SQLQuery.FieldByName('ETAZ_PP').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis3radek' + IntToStr(radek)).Components[1]).Text :=
        SQLQuery.FieldByName('ETAZ_PS').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis4radek' + IntToStr(radek)).Components[1]).Text := maj_druh + '/'
        + maj_kod;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis5radek' + IntToStr(radek)).Components[1]).Text :=
        SQLQuery.FieldByName('PROC_HS').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis6radek' + IntToStr(radek)).Components[1]).Text :=
        SQLQuery.FieldByName('OBMYTI').AsString + '/' +
        SQLQuery.FieldByName('OBN_DOBA').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'nadpis7radek' + IntToStr(radek)).Components[1]).Text :=
        SQLQuery.FieldByName('MZD').AsString;

      Inc(radek);

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's0001')).Text :=
        SQLQuery.FieldByName('HS').AsString;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's001')).Text :=
        SQLQuery.FieldByName('VEK').AsString;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's01')).Text :=
        SQLQuery.FieldByName('ZAKM').AsString;

    end;
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'nadpisVEKradek' + IntToStr(radek))).Text :=
      SQLQuery.FieldByName('VEK').AsString;
      vek := SQLQuery.FieldByName('VEK').AsInteger;
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'nadpisZAKMradek' + IntToStr(radek))).Text :=
      SQLQuery.FieldByName('ZAKM').AsString;

    SQLQuery.Close;

    // data o drevinach
    SQLQuery.SQL.Clear;
    SQLQuery.SQL.Add('SELECT count(*) as c from drevina WHERE VAZBA = ' + etazID);
    SQLQuery.OpenOrExecute;
    pocetDrevin := SQLQuery.FieldByName('c').AsInteger;
    (*
    setLength(drevinyEtaz, 10);
    for i := 0 to length(drevinyEtaz) - 1 do
    begin
      drevinyEtaz[i] := '';
    end;
    navrhCount := 0;
    while NOT SQLQuery.Eof do
    begin
      drevinyEtaz[navrhCount] := SQLQuery.FieldByName('DR_ZKR').AsString;
      Inc(navrhCount);
      SQLQuery.Next;
    end; *)
    SQLQuery.Close;

    SQLQuery.SQL.Clear;
    SQLQuery.SQL.Add('SELECT * from drevina WHERE VAZBA = ' + etazID);
    SQLQuery.OpenOrExecute;
    i := 0;
    etazZast := 0;
    zasoba1 := 0;
    souse := 0;
    zasobaC := 0;
    TVP := 0;
    TVO := 0;
    TOP := 0;
    TOO := 0;
    prorezavkyP := 0;
    zalProc := 0;
    zalP := 0;
    first := true;
    navrhIndex := -1;

    while NOT SQLQuery.Eof do
    begin
      stejnaDrevina := false;
      if first = true then
      begin
        SQLQuery2.SQL.Clear;
        SQLQuery2.SQL.Add('SELECT * from navrh WHERE Vazba = ' + etazID +
          ' AND N_Zkratka_dreviny = "000"');
        SQLQuery2.OpenOrExecute;

        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's19')).Text :=
          SQLQuery2.FieldByName('N_Nalehavost').AsString;
        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's20')).Text :=
          SQLQuery2.FieldByName('N_Plocha').AsString;
        prorezavkyP := prorezavkyP + SQLQuery2.FieldByName('N_Plocha').AsFloat;
        SQLQuery2.Close;
        first := false;
      end;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's0')).Text :=
        SQLQuery.FieldByName('DR_ZKR').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's1')).Text :=
        SQLQuery.FieldByName('ZAST').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's2')).Text :=
        SQLQuery.FieldByName('TLOUSTKA').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's3')).Text :=
        SQLQuery.FieldByName('VYSKA').AsString;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's4')).Text :=
        FloatToStr(RoundTo(VratObjem(SQLQuery.FieldByName('DR_ZKR').AsString, SQLQuery.FieldByName('TLOUSTKA').AsFloat,
        SQLQuery.FieldByName('VYSKA').AsFloat,vek,Status),-2));

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's5')).Text :=
        SQLQuery.FieldByName('BON_A').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's6')).Text :=
        SQLQuery.FieldByName('BON_R').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's7')).Text :=
        SQLQuery.FieldByName('GEN_KLAS').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's10')).Text :=
        SQLQuery.FieldByName('IMISE').AsString;
      etazZast := etazZast + SQLQuery.FieldByName('ZAST').AsInteger;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's12')).Text :=
        SQLQuery.FieldByName('PROC_SOUS').AsString;

      drevina := SQLQuery.FieldByName('DR_ZKR').AsString;
      listJehl := -1;

      if ((drevina = 'BKS') OR (drevina = 'BL') OR (drevina = 'BO') OR
        (drevina = 'BOC') OR (drevina = 'BOP') OR (drevina = 'BOX') OR
        (drevina = 'DG') OR (drevina = 'JAL') OR (drevina = 'JD') OR
        (drevina = 'JDJ') OR (drevina = 'JDK') OR (drevina = 'JDO') OR
        (drevina = 'JDV') OR (drevina = 'JDX') OR (drevina = 'JX') OR
        (drevina = 'KOS') OR (drevina = 'LMB') OR (drevina = 'MD') OR
        (drevina = 'MDX') OR (drevina = 'SM') OR (drevina = 'SMC') OR
        (drevina = 'SME') OR (drevina = 'SMO') OR (drevina = 'SMP') OR
        (drevina = 'SMS') OR (drevina = 'SMX') OR (drevina = 'SOJ') OR
        (drevina = 'TS') OR (drevina = 'VJ')) then

        listJehl := 1

      else if ((drevina = 'AK') OR (drevina = 'BB') OR (drevina = 'BK') OR
        (drevina = 'BR') OR (drevina = 'BRK') OR (drevina = 'BRP') OR
        (drevina = 'CER') OR (drevina = 'DB') OR (drevina = 'DBB') OR
        (drevina = 'DBC') OR (drevina = 'DBP') OR (drevina = 'DBS') OR
        (drevina = 'DBX') OR (drevina = 'DBZ') OR (drevina = 'HB') OR
        (drevina = 'HR') OR (drevina = 'JB') OR (drevina = 'JIV') OR
        (drevina = 'JL') OR (drevina = 'JLH') OR (drevina = 'JLV') OR
        (drevina = 'JR') OR (drevina = 'JS') OR (drevina = 'JSA') OR
        (drevina = 'JSU') OR (drevina = 'JV') OR (drevina = 'JVJ') OR
        (drevina = 'JVX') OR (drevina = 'KJ') OR (drevina = 'KL') OR
        (drevina = 'KR') OR (drevina = 'KS') OR (drevina = 'LMX') OR
        (drevina = 'LP') OR (drevina = 'LPS') OR (drevina = 'LPV') OR
        (drevina = 'LTX') OR (drevina = 'MK') OR (drevina = 'OL') OR
        (drevina = 'OLS') OR (drevina = 'OLZ') OR (drevina = 'OR') OR
        (drevina = 'ORC') OR (drevina = 'OS') OR (drevina = 'PJ') OR
        (drevina = 'PL') OR (drevina = 'SOL') OR (drevina = 'STR') OR
        (drevina = 'TP') OR (drevina = 'TPC') OR (drevina = 'TPS') OR
        (drevina = 'TPX') OR (drevina = 'TR') OR (drevina = 'VR')) then

        listJehl := 0;

      if (SQLQuery.FieldByName('STAV_ZPRAC').AsString.Equals('')) then
      begin
        // 'BKS','BL','BO','BOC','BOP','BOX','DG','JAL','JD','JDJ','JDK','JDO','JDV','JDX',
        // 'JX','KOS','LMB','MD','MDX','SM','SMC','SME','SMO','SMP','SMS','SMX','SOJ',
        // 'TS','VJ'
        case listJehl of
          // jehlicnate
          1:
            begin
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's11')).Text :=
                IntToStr(Round(SQLQuery.FieldByName('DR_ZAS_HA').AsFloat *
                0.90909));
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's13')).Text :=
                IntToStr(Round(SQLQuery.FieldByName('DR_ZAS_CELK').AsFloat *
                0.90909));
            end;
          // listante
          0:
            // 'AK','BB','BK','BR','BRK','BRP','CER','DB','DBB','DBC','DBP','DBS','DBX','DBZ','HB','HR','JB','JIV',
            // 'JL','JLH','JLV','JR','JS','JSA','JSU','JV','JVJ','JVX','KJ','KL','KR',
            // 'KS','LMX','LP','LPS','LPV','LTX','MK','OL','OLS','OLZ','OR','ORC','OS','PJ','PL',
            // 'SOL','STR','TP','TPC','TPS','TPX','TR','VR':
            begin
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's11')).Text :=
                IntToStr(Round(SQLQuery.FieldByName('DR_ZAS_HA').AsFloat *
                0.86956));
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's13')).Text :=
                IntToStr(Round(SQLQuery.FieldByName('DR_ZAS_CELK').AsFloat *
                0.86956));
            end;
          // ostatni/nezname, neodkornuju
          -1:
            begin
            end;
        end;
      end;

      zasoba1 := zasoba1 + StrToFloat
        (TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO)
        + 'radek' + IntToStr(radek) + 's11')).Text);
      souse := souse + SQLQuery.FieldByName('PROC_SOUS').AsFloat;
      zasobaC := zasobaC + StrToFloat
        (TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO)
        + 'radek' + IntToStr(radek) + 's13')).Text);

      ps1ha := ps1ha + StrToFloat
        (TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO)
        + 'radek' + IntToStr(radek) + 's11')).Text);
      psCelkem := StrToFloat(TLabel(HospKniha.ScaledLayout1.FindComponent('etaz'
        + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's13')).Text);

      SQLQuery2.SQL.Clear;
      SQLQuery2.SQL.Add('SELECT * from poskoz WHERE Vazba = ' +
        SQLQuery.FieldByName('ID').AsString);
      SQLQuery2.OpenOrExecute;

      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's8')).Text :=
        SQLQuery2.FieldByName('Druh_poskozeni').AsString;
      TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
        'radek' + IntToStr(radek) + 's9')).Text :=
        SQLQuery2.FieldByName('Stupen_poskozeni').AsString;
      SQLQuery2.Close;

      SQLQuery2.SQL.Clear;
      SQLQuery2.SQL.Add('SELECT N_Zkratka_dreviny from navrh WHERE Vazba = ' +
        etazID + ' AND (N_Druh_vykonu = 1 OR N_Druh_vykonu = 2 OR N_Druh_vykonu = 3 OR N_Druh_vykonu = 4 OR N_Druh_vykonu = 5 OR N_Druh_vykonu = 6 OR N_Druh_vykonu = 7)');
      SQLQuery2.OpenOrExecute;
      setLength(drevinyNavrh, 10);
      for i := 0 to length(drevinyNavrh) - 1 do
      begin
        drevinyNavrh[i] := '';
      end;
      navrhCount := 0;
      while NOT SQLQuery2.Eof do
      begin
        drevinyNavrh[navrhCount] := SQLQuery2.FieldByName
          ('N_Zkratka_dreviny').AsString;
        Inc(navrhCount);
        SQLQuery2.Next;
      end;
      SQLQuery2.Close;

      // tezby
      SQLQuery2.SQL.Clear;
      SQLQuery2.SQL.Add('SELECT * from navrh WHERE Vazba = ' + etazID +
        ' AND N_Zkratka_dreviny = "' + SQLQuery.FieldByName('DR_ZKR')
        .AsString + '"');
      SQLQuery2.OpenOrExecute;

      while NOT SQLQuery2.Eof do
      begin

        case SQLQuery2.FieldByName('N_Druh_vykonu').AsInteger of
          10:
            begin
              TOP := TOP + SQLQuery2.FieldByName('N_Plocha').AsFloat;
              // odkorneni
              if listJehl = 0 then
              begin
                TOO := TOO + (SQLQuery2.FieldByName('N_Objem').AsFloat
                  * 0.86956);
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                  IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's18')).Text :=
                  IntToStr(Round(SQLQuery2.FieldByName('N_Objem').AsFloat *
                  0.86956));
              end
              else
              begin
                TOO := TOO + (SQLQuery2.FieldByName('N_Objem').AsFloat
                  * 0.90909);
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                  IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's18')).Text :=
                  IntToStr(Round(SQLQuery2.FieldByName('N_Objem').AsFloat *
                  0.90909));
              end;

              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's17')).Text :=
                SQLQuery2.FieldByName('N_Plocha').AsString;

            end;
          11:
            begin
              TVP := TVP + SQLQuery2.FieldByName('N_Plocha').AsFloat;

              // odkorneni
              if listJehl = 0 then
              begin
                TVO := TVO + (SQLQuery2.FieldByName('N_Objem').AsFloat
                  * 0.86956);
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                  IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's16')).Text :=
                  IntToStr(Round(SQLQuery2.FieldByName('N_Objem').AsFloat *
                  0.86956));
              end
              else
              begin
                TVO := TVO + (SQLQuery2.FieldByName('N_Objem').AsFloat
                  * 0.90909);
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                  IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's16')).Text :=
                  IntToStr(Round(SQLQuery2.FieldByName('N_Objem').AsFloat *
                  0.90909));
              end;

              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's14')).Text :=
                SQLQuery2.FieldByName('N_Nalehavost').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's15')).Text :=
                SQLQuery2.FieldByName('N_Plocha').AsString;

            end;
          1, 2, 3, 4, 5, 6, 7:
            begin
              stejnaDrevina := true; (*
                zalProc := zalProc + SQLQuery2.FieldByName('N_Procento').AsFloat;
                zalP := zalP + SQLQuery2.FieldByName('N_Plocha').AsFloat;
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's21')).Text :=
                SQLQuery2.FieldByName('N_Druh_vykonu').AsString;
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's22')).Text :=
                SQLQuery2.FieldByName('N_Zkratka_dreviny').AsString;
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's23')).Text :=
                SQLQuery2.FieldByName('N_Procento').AsString;
                TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's24')).Text :=
                SQLQuery2.FieldByName('N_Plocha').AsString; *)
            end;
        else
          begin
          end;
        end;
        SQLQuery2.Next;
      end;
      SQLQuery2.Close;
      (*
      if (stejnaDrevina = false) then
      begin

        for i := 0 to length(drevinyNavrh) - 1 do
        begin (*
            drevinaMimo := false;
            for x := 0 to length(drevinyEtaz) - 1 do
            begin
            if (drevinyEtaz[x] = drevinyNavrh[i]) then
            begin
            drevinaMimo := true;
            end;
            end;

          //if ((drevinyNavrh[i] <> SQLQuery.FieldByName('DR_ZKR').AsString) AND
           // (i > navrhIndex)) then
          begin

            SQLQuery4.SQL.Clear;
            SQLQuery4.SQL.Add('SELECT * from navrh WHERE Vazba = ' + etazID +
              ' AND N_Zkratka_dreviny = "' + drevinyNavrh[i] +
              '" AND (N_Druh_vykonu = 1 OR N_Druh_vykonu = 2 OR N_Druh_vykonu = 3 OR N_Druh_vykonu = 4 OR N_Druh_vykonu = 5 OR N_Druh_vykonu = 6 OR N_Druh_vykonu = 7)');
            SQLQuery4.OpenOrExecute;

            while NOT SQLQuery4.Eof do
            begin
              zalProc := zalProc + SQLQuery4.FieldByName('N_Procento').AsFloat;
              zalP := zalP + SQLQuery4.FieldByName('N_Plocha').AsFloat;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's21')).Text :=
                SQLQuery4.FieldByName('N_Druh_vykonu').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's22')).Text :=
                SQLQuery4.FieldByName('N_Zkratka_dreviny').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's23')).Text :=
                SQLQuery4.FieldByName('N_Procento').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's24')).Text :=
                SQLQuery4.FieldByName('N_Plocha').AsString;
              SQLQuery4.Next;
            end;
            SQLQuery4.Close;

            navrhIndex := i;
            //break;
          end;
        end;
      end;*)
      SQLQuery.Next;
      Inc(radek);
      stejnaDrevina := false;
    end;

    SQLQuery.Close;


    for i := 0 to length(drevinyNavrh) - 1 do
        begin
            SQLQuery4.SQL.Clear;
            SQLQuery4.SQL.Add('SELECT * from navrh WHERE Vazba = ' + etazID +
              ' AND N_Zkratka_dreviny = "' + drevinyNavrh[i] +
              '" AND (N_Druh_vykonu = 1 OR N_Druh_vykonu = 2 OR N_Druh_vykonu = 3 OR N_Druh_vykonu = 4 OR N_Druh_vykonu = 5 OR N_Druh_vykonu = 6 OR N_Druh_vykonu = 7)');
            SQLQuery4.OpenOrExecute;

            while NOT SQLQuery4.Eof do
            begin
              zalProc := zalProc + SQLQuery4.FieldByName('N_Procento').AsFloat;
              zalP := zalP + SQLQuery4.FieldByName('N_Plocha').AsFloat;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek-pocetDrevin+i) + 's21')).Text :=
                SQLQuery4.FieldByName('N_Druh_vykonu').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek-pocetDrevin+i) + 's22')).Text :=
                SQLQuery4.FieldByName('N_Zkratka_dreviny').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek-pocetDrevin+i) + 's23')).Text :=
                SQLQuery4.FieldByName('N_Procento').AsString;
              TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' +
                IntToStr(etazNO) + 'radek' + IntToStr(radek-pocetDrevin+i) + 's24')).Text :=
                SQLQuery4.FieldByName('N_Plocha').AsString;
              SQLQuery4.Next;
            end;
            SQLQuery4.Close;

          end;




    // pokud je cela etaz holina a je v navrhu zalesneni
    if (first = true) then
    begin
      SQLQuery4.SQL.Clear;
      SQLQuery4.SQL.Add('SELECT * from navrh WHERE Vazba = ' + etazID +
        ' AND (N_Druh_vykonu = 1 OR N_Druh_vykonu = 2 OR N_Druh_vykonu = 3 OR N_Druh_vykonu = 4 OR N_Druh_vykonu = 5 OR N_Druh_vykonu = 6 OR N_Druh_vykonu = 7)');
      SQLQuery4.OpenOrExecute;

      while NOT SQLQuery4.Eof do
      begin

        rect := CloneRect(HospKniha.Rectangle32, 0, 32 * radek,
          'radekRect' + IntToStr(radek));
        HospKniha.ScaledLayout1.AddObject(rect);
        HospKniha.Height := HospKniha.Height + 33;
        HospKniha.ScaledLayout1.OriginalHeight :=
          HospKniha.ScaledLayout1.OriginalHeight + 33;
        HospKniha.ScaledLayout1.Height := HospKniha.ScaledLayout1.Height + 33;

        for z := 0 to 24 do
        begin
          newLabel := CloneLabel(HospKniha.Label93, 120 + 40 * z, 32 * radek,
            'etaz' + IntToStr(etazNO) + 'radek' + IntToStr(radek) + 's' +
            IntToStr(z));
          newLabel.Text := '';
          HospKniha.ScaledLayout1.AddObject(newLabel);
        end;

        zalProc := zalProc + SQLQuery4.FieldByName('N_Procento').AsFloat;
        zalP := zalP + SQLQuery4.FieldByName('N_Plocha').AsFloat;
        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's21')).Text :=
          SQLQuery4.FieldByName('N_Druh_vykonu').AsString;
        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's22')).Text :=
          SQLQuery4.FieldByName('N_Zkratka_dreviny').AsString;
        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's23')).Text :=
          SQLQuery4.FieldByName('N_Procento').AsString;
        TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
          'radek' + IntToStr(radek) + 's24')).Text :=
          SQLQuery4.FieldByName('N_Plocha').AsString;
        SQLQuery4.Next;
        Inc(radek);
      end;
      SQLQuery4.Close;
      Dec(radek);

      //first := false;
    end;

    Inc(radek);

    // soucet etaze
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's1')).Text := FloatToStr(etazZast);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's11')).Text := FloatToStr(zasoba1);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's12')).Text := FloatToStr(souse);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's13')).Text := FloatToStr(zasobaC);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's15')).Text := FloatToStr(TVP);

    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's16')).Text := IntToStr(Round(TVO));

    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's17')).Text := FloatToStr(TOP);

    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's18')).Text := IntToStr(Round(TOO));

    if(TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's23')).Text.Equals('')) then
      begin
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's23')).Text := FloatToStr(zalProc);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's24')).Text := FloatToStr(zalP);
      end;
    Inc(radek);
    Inc(etazNO);
    SQLQuery3.Next;
  end;
  SQLQuery3.Close;

  // soucet PS
  if(first = true) then
  begin
    Dec(radek);
  end;
  if etazCount = 1 then
  begin
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz1radek' + IntToStr(radek)
      + 's11')).Text := FloatToStr(ps1ha);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz1radek' + IntToStr(radek)
      + 's13')).Text := FloatToStr(psCelkem);
  end
  else
  begin
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's11')).Text := FloatToStr(ps1ha);
    TLabel(HospKniha.ScaledLayout1.FindComponent('etaz' + IntToStr(etazNO) +
      'radek' + IntToStr(radek) + 's13')).Text := FloatToStr(psCelkem);

  end;


  // HospKniha.Label236.Text := FloatToStr(prorezavkyP);

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from phs_orgur1 WHERE KOD = ' +
    HospKniha.Label14.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label14.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from phs_orgur2 WHERE KOD = ' +
    HospKniha.Label16.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label16.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT * from phs_orgur3 WHERE KOD = ' +
    HospKniha.Label18.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label18.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  // uprava dat podle ciselniku
  DBConnection.Params.Values['Database'] := DBPath + '/ciselniky.s3db';

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT POPIS from cis_leob WHERE Kod = "' +
    HospKniha.Label2.Text+'"');
  SQLQuery.OpenOrExecute;
  HospKniha.Label2.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT POPIS from zvl_stat WHERE KOD = ' +
    HospKniha.Label6.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label6.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT Popis from orp WHERE Kod = ' +
    HospKniha.Label40.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label40.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT POPIS from kategori WHERE Kod = ' +
    HospKniha.Label4.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label4.Text := SplitString(SQLQuery.FieldByName('POPIS')
    .AsString, '-')[0];
  SQLQuery.Close;

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT POPIS from ku6 WHERE KOD = ' +
    HospKniha.Label46.Text);
  SQLQuery.OpenOrExecute;
  HospKniha.Label46.Text := SQLQuery.FieldByName('POPIS').AsString;
  SQLQuery.Close;

  DBConnection.Params.Values['Database'] := DBPath + '/LHC_' + LHC + '_' + rok
    + '.s3db';

  HospKniha.Show;
end;

// zobrazeni hosp.knihy
procedure TForm2.Button3Click(Sender: TObject);
var
  LHC, rok: String;
begin
  if (ComboBox1.Items.Count > 0 AND ComboBox2.Items.Count AND
    ComboBox3.Items.Count AND ComboBox4.Items.Count) then
  begin
    LHC := SplitString(ListBox1.Items[ListBox1.ItemIndex], ' ')[0];
    rok := SplitString(SplitString(ListBox1.Items[ListBox1.ItemIndex], '(')
      [1], '-')[0];

    zobrazHK(LHC, rok, ComboBox1.Items[ComboBox1.ItemIndex],
      ComboBox2.Items[ComboBox2.ItemIndex],
      ComboBox3.Items[ComboBox3.ItemIndex],
      ComboBox4.Items[ComboBox4.ItemIndex]);
  end;
end;

// close button
procedure TForm2.Button4Click(Sender: TObject);
begin
  MainActivity.finish;
end;

// zmena oddeleni

procedure TForm2.ComboBox1Change(Sender: TObject);
var
  oddeleni: String;
begin

  if(ComboBox1.ItemIndex >= 0) then
  begin
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from oddeleni WHERE ODD = ' + ComboBox1.Items
    [ComboBox1.ItemIndex]);
  SQLQuery.OpenOrExecute;
  oddeleni := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  firstODD := oddeleni;
  LoadDIL(oddeleni);
  LoadPOR(firstDIL);
  LoadPS(firstPOR);
  // LoadEtaz(firstPS);
  end;
end;

// zmena dilce
procedure TForm2.ComboBox2Change(Sender: TObject);
var
  dilec: String;
begin
  if(ComboBox2.ItemIndex >= 0) then
  begin
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from dilec WHERE DIL = "' + ComboBox2.Items
    [ComboBox2.ItemIndex] + '" AND VAZBA = ' + firstODD);
  SQLQuery.OpenOrExecute;
  dilec := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  firstDIL := dilec;
  LoadPOR(dilec);
  LoadPS(firstPOR);
  // LoadEtaz(firstPS);
  end;
end;

// zmena porostu
procedure TForm2.ComboBox3Change(Sender: TObject);
var
  porost: String;
begin
  if(ComboBox3.ItemIndex >= 0) then
  begin
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from porost WHERE POR = "' + ComboBox3.Items
    [ComboBox3.ItemIndex] + '" AND VAZBA = ' + firstDIL);
  SQLQuery.OpenOrExecute;
  porost := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  firstPOR := porost;
  LoadPS(porost);
  end;
  // LoadEtaz(firstPS);
end;

// zmena skupiny
(*
  procedure TForm2.ComboBox4Change(Sender: TObject);
  var
  skupina: String;
  begin

  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('SELECT ID from ps WHERE PSK = "' + ComboBox4.Items
  [ComboBox4.ItemIndex] + '" AND VAZBA = ' + firstPOR);
  SQLQuery.OpenOrExecute;
  skupina := SQLQuery.FieldByName('ID').AsString;
  SQLQuery.Close;

  firstPS := skupina;
  LoadEtaz(skupina);
  end;
*)

// init
procedure TForm2.FormCreate(Sender: TObject);
var
  HomePath: String;
  RootNode, CurNode: IXMLNODE;
  XMLDocument: IXMLDocument;
  // nacteni configu
begin
  rozmery := true;
  HomePath := TPath.GetHomePath + '/miniHeletaxConf.xml';
  if TFile.Exists(HomePath) then
  begin
    XMLDocument := LoadXMLDocument(HomePath);
    XMLDocument.Active := true;
    RootNode := XMLDocument.DocumentElement;
    CurNode := RootNode.ChildNodes['DBPath'];
    DBPath := CurNode.Text;
    XMLDocument.Active := false;
    Application.ProcessMessages;
    LoadLHC(DBPath);
  end
  // pripadne default
  else
  begin
    DBPath := '/';
    Application.ProcessMessages;
    LoadLHC(DBPath);
  end;

  nactiTabulky;
end;

// vyber LHC
procedure TForm2.ListBox1ItemClick(const Sender: TCustomListBox;
  const AItem: TListBoxItem);
var
  LHC, rok: String;
  first: boolean;

begin

  LHC := SplitString(ListBox1.Items[ListBox1.ItemIndex], ' ')[0];
  rok := SplitString(SplitString(ListBox1.Items[ListBox1.ItemIndex], '(')
    [1], '-')[0];
  // nacitani comboboxu
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  Application.ProcessMessages;
  DBConnection.Params.Values['Database'] := DBPath + '/LHC_' + LHC + '_' + rok
    + '.s3db';
  ComboBox1.Items.Clear;
  ComboBox2.Items.Clear;
  ComboBox3.Items.Clear;
  ComboBox4.Items.Clear;
  // ComboBox6.Items.Clear;
  LoadODD;
  LoadDIL(firstODD);
  LoadPOR(firstDIL);
  LoadPS(firstPOR);
  // LoadEtaz(firstPS);
  Application.ProcessMessages;

end;

// nacteni comba se oddelenima
procedure TForm2.LoadODD;
var
  first: boolean;
begin
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  first := false;
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('Select ODD, ID from oddeleni');
  SQLQuery.OpenOrExecute;
  ComboBox1.Items.Clear;

  while NOT SQLQuery.Eof do
  begin
    if not first then
    begin
      firstODD := SQLQuery.FieldByName('ID').AsString;
      first := true;

    end;
    ComboBox1.Items.Add(SQLQuery.FieldByName('ODD').AsString.Trim);
    SQLQuery.Next;
    Application.ProcessMessages;
  end;
  ComboBox1.ItemIndex := 0;
  SQLQuery.Close;
  first := false;
  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;
end;

// nacteni comba se dilcema
procedure TForm2.LoadDIL(oddeleni: String);
var
  first: boolean;
begin
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  first := false;
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('Select DIL, ID from dilec WHERE vazba = ' + oddeleni);
  SQLQuery.OpenOrExecute;
  ComboBox2.Items.Clear;

  while NOT SQLQuery.Eof do
  begin
    if not first then
    begin
      firstDIL := SQLQuery.FieldByName('ID').AsString;
      first := true;

    end;
    ComboBox2.Items.Add(SQLQuery.FieldByName('DIL').AsString.Trim);
    SQLQuery.Next;
    Application.ProcessMessages;
  end;
  ComboBox2.ItemIndex := 0;
  SQLQuery.Close;
  first := false;
  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;
end;

// nacteni comba se porostama
procedure TForm2.LoadPOR(dilec: String);
var
  first: boolean;
begin
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  first := false;
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('Select POR, ID from porost WHERE vazba = ' + dilec);
  SQLQuery.OpenOrExecute;
  ComboBox3.Items.Clear;

  while NOT SQLQuery.Eof do
  begin
    if not first then
    begin
      firstPOR := SQLQuery.FieldByName('ID').AsString;
      first := true;

    end;
    ComboBox3.Items.Add(SQLQuery.FieldByName('POR').AsString.Trim);
    SQLQuery.Next;
    Application.ProcessMessages;
  end;
  ComboBox3.ItemIndex := 0;
  SQLQuery.Close;
  first := false;
  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;

end;

// nacteni comba se skupinama
procedure TForm2.LoadPS(porost: String);
var
  first: boolean;
begin
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  first := false;
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('Select PSK, ID from ps WHERE vazba = ' + porost);
  SQLQuery.OpenOrExecute;
  ComboBox4.Items.Clear;

  while NOT SQLQuery.Eof do
  begin
    if not first then
    begin
      firstPS := SQLQuery.FieldByName('ID').AsString;
      first := true;

    end;
    ComboBox4.Items.Add(SQLQuery.FieldByName('PSK').AsString.Trim);
    SQLQuery.Next;
    Application.ProcessMessages;
  end;
  ComboBox4.ItemIndex := 0;
  SQLQuery.Close;
  first := false;
  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;
end;

(*
  procedure TForm2.LoadEtaz(skupina: String);
  begin

  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  SQLQuery.SQL.Clear;
  SQLQuery.SQL.Add('Select ETAZ, ID from etaz WHERE vazba = ' + skupina);
  SQLQuery.OpenOrExecute;
  ComboBox6.Items.Clear;

  while NOT SQLQuery.Eof do
  begin
  ComboBox6.Items.Add(SQLQuery.FieldByName('ETAZ').AsString.Trim);
  SQLQuery.Next;
  Application.ProcessMessages;
  end;
  ComboBox6.ItemIndex := 0;
  SQLQuery.Close;

  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;
  end;
*)

// nahrani seznamu LHC
procedure TForm2.LoadLHC(DataPath: String);
var
  SPath: String;
  Path: TPath;
  Kod: String;
  Nazev: String;
  Datum: String;
  Datum2: String;
begin
  ListBox1.Items.Clear;
  Label2.Text := DataPath;
  AniIndicator1.Visible := true;
  AniIndicator1.Enabled := true;
  Application.ProcessMessages;
  for SPath in TDirectory.GetFiles(DataPath) do
  begin
    if Path.GetFileName(SPath).StartsWith('LHC') AND Path.GetExtension(SPath)
      .Equals('.s3db') then
    begin
      DBConnection.Params.Values['Database'] := SPath;
      SQLQuery.SQL.Clear;
      SQLQuery.SQL.Add('Select * from lhc');
      SQLQuery.OpenOrExecute;
      while NOT SQLQuery.Eof do
      begin
        Kod := SplitString(SQLQuery.FieldByName('LHC_KOD').AsString, ',')[0];
        Nazev := SQLQuery.FieldByName('LHC_NAZ').AsString;
        Datum := SQLQuery.FieldByName('LHP_OD').AsString;
        Datum2 := SQLQuery.FieldByName('LHP_DO').AsString;
        ListBox1.Items.Add(Kod + ' - ' + Nazev + ' (' +
          SplitString(SplitString(Datum, '.')[2], ' ')[0] + '-' +
          SplitString(SplitString(Datum2, '.')[2], ' ')[0] + ')');
        SQLQuery.Next;
        Application.ProcessMessages;
      end;
      SQLQuery.Close;

    end;
  end;
  AniIndicator1.Visible := false;
  AniIndicator1.Enabled := false;
  Application.ProcessMessages;

end;

// klonovani labelu
function TForm2.CloneLabel(source: TLabel; posunX, posunY: Integer;
  jmeno: String): TLabel;
var
  newLabel: TLabel;
begin

  if HospKniha.ScaledLayout1.FindComponent(jmeno) = nil then
  begin
    newLabel := TLabel(source.Clone(HospKniha.ScaledLayout1));
    newLabel.Name := jmeno;
    newLabel.Position.x := source.Position.x + posunX;
    newLabel.Position.Y := source.Position.Y + posunY;
    Result := newLabel;
  end
  else
  begin
    Result := TLabel(HospKniha.ScaledLayout1.FindComponent(jmeno));
  end;
end;

// klonovani obdelnicku
function TForm2.CloneRect(source: TRectangle; posunX, posunY: Integer;
  jmeno: String): TRectangle;
var
  newRect: TRectangle;
begin
  if HospKniha.ScaledLayout1.FindComponent(jmeno) = nil then
  begin
    newRect := TRectangle(source.Clone(HospKniha.ScaledLayout1));
    newRect.Name := jmeno;
    newRect.Position.x := newRect.Position.x + posunX;
    newRect.Position.Y := newRect.Position.Y + posunY;
    Result := newRect;
  end
  else
  begin
    Result := TRectangle(HospKniha.ScaledLayout1.FindComponent(jmeno));
  end;
end;


end.
