unit UObjemULT;
{Objem ULT s interpolaci v tabulkach
 Interpoluje se vytvarnice. Jako vytvarnice je zde minen podil objemu stromu a objemu hranolu
    (aby se nemuselo nasobit a delit pi/4 )
      }

{
  Navod k pouziti jednotky:
  --------------------------
  1. Na zacatku je nutno volat proceduru nactiTabulky.
      Staci ji volat po startu jen jednou.
      Ta nacte tabelovane hodnoty z textovych souboru do pameti.

  2. Vlastni vypocet objemu zajistuje funkce VratObjem.
     Parametry funkce:
        DrZkr - zkratka dreviny podle ciselniku ISLH
        d - tloustka v cm
        h - vyska v m
        vek - vek v rocich
           Vek se uplatnuje u JD a BO, ktere maji ruzne tabulky pro ruzna vekova rozpeti .
        status  = 0  vypocet OK
                = 1  d nebo h mimo obor tabulek - extrapolace
                = -1 chybne vstupni parametry

   Soubory tabulek  (pokyn pro instalaci)
   --------------------
   Tabelovane hodnoty jsou v textovym souborech. Tyto soubory
   musi byt ulozeny ve slozce ObjULT, a ta musi byt umistena v adresari s programem
    Seznam textovych souboru:
     HT_Ak.txt, HT_Bk.txt, HT_Bo_41.txt, HT_Bo_81.txt, HT_Br.txt,
     HT_Db.txt, HT_HB.txt, HT_JD_41.txt, HT_JD_81.txt, HT_JD_121.txt,
     HT_JS.txt, HT_MD.txt, HT_OL.txt, HT_SM.txt, HT_VV.txt,
     ULT_Dreviny.txt

    Pozn. Pokud bude potreba umistit tabulky do jine slozky (treba "Ciselniky"),
          je potreba modifikovat funkci FCestaData
 }

interface

uses
  SysUtils, Classes, Math,System.IOUtils;

type
TTloustka=record
  d:real;
  ihmin, ihmax:integer;
  hmin, hmax, hdif:real;
  v:array of real;
end;

TDrevinaULT=class
  drevina:string;
  drIndex:integer;
  fname:string;
  tmin,tmax:integer;
  dmin, dmax, ddif:real;
  dr_hmin, dr_hmax, dr_hdif:real;
  Tloustky:array of TTloustka;
  VytV:TTloustka;
  procedure NaplnTab(Vstup:TStrings);
  procedure ClearTl;
  destructor Destroy;  override;
end;


procedure nactiTabulky;
{Tato funkce se musi volat pred prvnim pouzitim funkce VratObjem }

function VratObjem(DrZkr:string;d,h:real;vek:Integer;var Status:Integer):real;
{objem ULT
  vstupy:
    DrZkr - zkratka dreviny podle ciselniku ISLH
    d - tloustka v cm
    h - vyska v m
    vek - vek v rocich
       Vek se uplatnuje u JD a BO, ktere maji ruzne tabulky pro ruzna vekova rozpeti .  }

{  Nasledujici funkce jsou podpurne a neni nutno je primo volat }

function VratObjemULT(TabDrev:string;d,h:real;var Status:Integer):real;
{objem ULT, funkce je volana funkci VratObjem, ktera prevadi zkratky drevin ISLH
    ma kody tabulkovych drevin ULT
  vstupy:
    TabDrev - kod skupiny drevin ULT pro kterou plati jedny tabulky
              pro BO a JD je vice kodu podle vekovych rozpeti
    d - tloustka v cm
    h - vyska v m   }


function VratVytvarnici(TabDrev:string;d,h:real;var Status:Integer):real;
{  Vytvarnice - funkce je volana funkci VratObjemULT
    Jako vytvarnice je zde minen podil objemu stromu a objemu hranolu
      status  = 0  vypocet OK
         = 1  d nebo h mimo obor tabulek - extrapolace
         = -1 chybne vstupni parametry }

function VratVytvVysku(drev:string;vyska:integer):real;
{Vytvarnicova vyska pro tloustky presahujici rozsah tabulek
   funkce je volana funkci VratObjemULT}

function IndexDrevinyULT(drev:string):integer;
  {funkce vrati index drevinz ULT podle kodu}

procedure zrustabulky;

//function FCestaData:String;
{funkce vrati uplnou cestu k textovym souborum s tabulkami
 ty musi byt ulozeny ve slozce ObjULT, ktera je umistena v adresari s programem}


var
  ULT:array of TDrevinaULT;
  DrevLHPNaULT:TStringList;

implementation

procedure nactiDreviny;forward;
procedure nactiVytvVysky;forward;

{TDrevinaULT}

destructor TDrevinaULT.Destroy;
begin
  ClearTl;
  inherited;
end;

procedure TDrevinaULT.ClearTl;
var
  i:integer;
begin
  for i:=0 to length(Tloustky)-1 do setlength(Tloustky[i].v,0);
  setlength(tloustky,0);
end;

procedure TDrevinaULT.NaplnTab(Vstup: TStrings);
var
  i,j:integer;
  SLTlou:TStringList;
  aVysky:Array of integer;
  minv:boolean;
begin
  for i:=Vstup.Count-1 downto 0 do
    if trim(vstup[i])='' then
       Vstup.Delete(i);
  SLTlou:=Tstringlist.Create;
  SLTlou.Text:=Vstup[0];   {vysky}
  SLTlou.Text:=StringReplace(SLTlou.Text,chr(9),chr(13)+chr(10),[rfReplaceAll	]);
  setlength(aVysky,SLTlou.Count-1);
  self.ClearTl;
  for i:=1 to SLTlou.Count-1 do aVysky[i-1]:=StrToIntDef(SLTlou[i],-1);
  dr_hmin:=aVysky[0];
  dr_hmax:=aVysky[length(aVysky)-1];
  dr_hdif:=aVysky[1]-aVysky[0];
  setlength(self.Tloustky, Vstup.Count-1);
  for i:=1 to  Vstup.Count-1 do
  begin
    SLTlou.Text:=Vstup[i];   {radek tloustky}
    SLTlou.Text:=StringReplace(SLTlou.Text,chr(9),chr(13)+chr(10),[rfReplaceAll	]);
    if i=1 then dmin:=StrToIntDef(SLTlou[0],0);
    if i=2 then ddif:=StrToIntDef(SLTlou[0],0)-dmin;
    if (i+1)=Vstup.Count then dmax:=StrToIntDef(SLTlou[0],0);
    Tloustky[i-1].d:=StrToIntDef(SLTlou[0],0);
    minv:=true;
    setlength(Tloustky[i-1].v,SLTlou.Count-1);
    for j:=1 to SLTlou.Count-1 do
    begin
      if trim(SLTlou[j])<>'' then
      begin
        if minv then Tloustky[i-1].hmin:=aVysky[j-1];
        if minv then Tloustky[i-1].hdif:=aVysky[j]-aVysky[j-1];
        if minv then Tloustky[i-1].ihmin:=j-1;
        minv:=false;
        Tloustky[i-1].hmax:=aVysky[j-1];
        Tloustky[i-1].ihmax:=j-1;
        Tloustky[i-1].v[j-1]:=StrToIntDef(SLTlou[j],0)/100;
      end
        else
      begin
         if minv then Tloustky[i-1].v[j-1]:=-1
         else Tloustky[i-1].v[j-1]:=-2;
      end;
    end;
  end;
  dr_hmin:=Tloustky[0].hmin;
  dr_hdif:=Tloustky[0].hdif;
  dr_hmax:=Tloustky[length(Tloustky)-1].hmax;
  SlTlou.Free;
end;

procedure nactiTabulky;
var
  i:integer;
  DrevULT:TstringList;
begin
  NactiDreviny;
  nactiVytvVysky;
  DrevULT:=TstringList.Create;
  for i:=0 to length(ULT)-1 do
  begin
    DrevULT.LoadFromFile(TPath.GetDocumentsPath + PathDelim+ULT[i].fname);
    ULT[i].NaplnTab(DrevULT);
  end;
  DrevULT.Free;
end;

{funkce vrati uplnou cestu k textovym souborum s tabulkami
 ty musi byt ulozeny ve slozce ObjULT, ktera je umistena v adresari s programem
function FCestaData: String;
begin
  result:=ExtractFilePath(Application.ExeName)+'ObjULT\';
end;
 }
procedure nactiDreviny;
var
  i:integer;
  p,l:integer;
  s:string;
  SeznULT:TStringList;
begin
  zrustabulky;
  if length(ULT)=0 then DrevLHPNaULT:=TstringList.Create;
  try
    DrevLHPNaULT.Clear;
  except
    on EAccessViolation do
      DrevLHPNaULT:=TstringList.Create;
  end;
   {nacteni prevodniku zkratek drevin LHP na kod ULT}
  DrevLHPNaULT.LoadFromFile(TPath.GetDocumentsPath + PathDelim +'ULT_Dreviny.txt');

  SeznULT:=TstringList.Create;
    {nacteni seznamu drevin ULT ze souboru vytvarnicovych vysek}
  SeznULT.LoadFromFile(TPath.GetDocumentsPath + PathDelim+'HT_VV.txt');
  SeznULT.Delete(0);      {hlavicka}
  for i:=0 to  SeznULT.Count-1 do
  begin
    s:=SeznULT[i];
    p:=pos(chr(9),s);
    l:=length(s);
    delete(s,p,l-p+1);
    SeznULT[i]:=s;
  end;
  setlength(ULT,SeznULT.Count);
  for i:=0 to  SeznULT.Count-1 do
  begin
    ULT[i]:=TDrevinaULT.Create;
    ULT[i].drevina:=SeznULT[i];
    ULT[i].tmin:=0;
    ULT[i].tmax:=high(i);
    s:=SeznULT[i];
    if s='JD_41' then ULT[i].tmax:=80;
    if s='JD_81' then begin ULT[i].tmin:=81; ULT[i].tmax:=120; end;
    if s='JD_121' then ULT[i].tmin:=121;
    if s='BO_41' then ULT[i].tmax:=80;
    if s='BO_81' then ULT[i].tmin:=81;
    ULT[i].fname:='HT_'+s+'.txt';
  end;
  SeznULT.Free;

end;

procedure nactiVytvVysky;
var
  i,j,kdr:integer;
  nv:Integer;
  aVysky:Array of integer;
  minv:boolean;
  SLTabVt:TStringList;
  SLDrevVt:TStringList;
begin
  SLTabVt:=TStringList.Create;
  SLDrevVt:=TStringList.Create;

  SLTabVt.LoadFromFile(TPath.GetDocumentsPath + PathDelim+'HT_VV.txt');
  SLDrevVt.Text:=SLTabVt[0];        {1. radek = vysky}
  SLDrevVt.Text:=StringReplace(SLDrevVt.Text,chr(9),chr(13)+chr(10),[rfReplaceAll	]);
  setlength(aVysky,SLDrevVt.Count-1);
  for i:=1 to SLDrevVt.Count-1 do aVysky[i-1]:=StrToIntDef(SLDrevVt[i],-1);

  for i:=1 to  SLTabVt.Count-1 do
  begin
    SLDrevVt.Text:=SLTabVt[i];    {radek dreviny}
    SLDrevVt.Text:=StringReplace(SLDrevVt.Text,chr(9),chr(13)+chr(10),[rfReplaceAll	]);
    kdr:=IndexDrevinyULT(SLDrevVt[0]);
    nv:=0;
    minv:=true;
    if nv >= length(ULT[kdr].VytV.v) then setlength(ULT[kdr].VytV.v,nv+1);
    if kdr>=0 then
      for j:=1 to SLDrevVt.Count-1 do
        if trim(SLDrevVt[j])<>'' then
    begin
        nv:=nv+1;
        if minv then ULT[kdr].VytV.hmin:=aVysky[j-1];
        if minv then ULT[kdr].VytV.hdif:=aVysky[j]-aVysky[j-1];
        if minv then ULT[kdr].VytV.ihmin:=nv-1;
        minv:=false;
        ULT[kdr].VytV.hmax:=aVysky[j-1];
        ULT[kdr].VytV.ihmax:=nv-1;
        setlength(ULT[kdr].VytV.v,nv);
        ULT[kdr].VytV.v[nv-1]:=StrToIntDef(SLDrevVt[j],0)/100;
    end;
  end;

  setlength(aVysky,0);
  SLTabVt.Free;
  SLDrevVt.Free;
end;

procedure zrustabulky;
var
  i:integer;
begin
  if length(ULT)>0 then
  begin
    for i:=0 to length(ULT)-1 do
    begin
      try
        ULT[i].Free;
      except
        on e:exception do
        begin
        end;
      end;
    end;
  end;
end;

function IndexDrevinyULT(drev: string): integer;
var
  i:integer;
begin
  result:=-1;
  for i:=0 to length(ULT)-1 do
    if ULT[i].drevina=drev then
  begin
    result:=i;
    break;
  end;
end;

function VratVytvVysku(drev: string; vyska: integer): real;
var
  i,k:integer;
  r:real;
begin
  result:=0;
  i:=IndexDrevinyULT(drev);
  if vyska>= ULT[i].VytV.hmin then
    if vyska<= ULT[i].VytV.hmax then
  begin
    r:=int((vyska-ULT[i].VytV.hmin)/ULT[i].VytV.hdif);
    k:=round(r);
    result:=ULT[i].VytV.v[k];
  end;
end;

function VratObjem(DrZkr:string;d,h:real;vek:Integer;var Status:Integer):real;
var
  DrTab:string;
begin
  DrTab:=DrevLHPNaULT.Values[DrZkr];
  if DrTab='JD' then
    case vek of
      0..80:DRTab:=DrTab+'_41';
      81..120: DRTab:=DrTab+'_81';
      else DRTab:=DrTab+'_121';
    end;
  if DrTab='BO' then
    case vek of
      0..80:DRTab:=DrTab+'_41';
      else DRTab:=DrTab+'_81';
    end;

  result:=VratObjemULT(DrTab,d,h,Status);
end;

function VratObjemULT(TabDrev:string;d,h:real;var Status:Integer):real;
begin
  result:=VratVytvarnici(TabDrev,d,h,Status);
  result:=result*d*d*h/10000;
end;

function VratVytvarnici(TabDrev:string;d, h: real;var Status:Integer): real;
var
  idrev:integer;
  id1:integer;
  ih1:integer;
  d1,d2:real;
  h1, h2:real;
  td1h1, td1h2, td2h1, td2h2:real;  {vytvarnice}
  rint,qint:real;

  function TabVytv(ULTDrev:TDrevinaULT;pd,ph:real;status:integer):real;
  {status
    1. cislice - tloustka
    2. cislice -- vyska

    1 - v rozmezi
    2 - pod dolni mezi
    3 - nad horni mezi
    }
  var
    id,ih:integer;
    rd,rh:real;
    iht:integer;
  begin
    status:=11;
    rd:=pd;
    rh:=ph;
    id:=round((pd-ULTDrev.dmin)/ULTDrev.ddif);
    if pd<ULTDrev.dmin then
    begin
      id:=0;
      rd:=ULTDrev.dmin;
      status:=status+10;
    end;
    if pd>ULTDrev.dmax then
    begin
      id:=length(ULTDrev.Tloustky)-1;
      rd:=ULTDrev.dmax;
      status:=status+20;
    end;
    ih:=round((ph-ULTDrev.dr_hmin)/ULTDrev.dr_hdif);
    if ph<ULTDrev.Tloustky[id].hmin then
    begin
      ih:=ULTDrev.Tloustky[id].ihmin;
      rh:=ULTDrev.Tloustky[id].hmin;
      status:=status+1;
    end;
    if ph>ULTDrev.Tloustky[id].hmax then
    begin
      ih:=ULTDrev.Tloustky[id].ihmax;
      rh:=ULTDrev.Tloustky[id].hmax;
      status:=status+2;
    end;
    result:=0;
    if (rd*rh) <> 0 then result:=ULTDrev.Tloustky[id].v[ih]/rh/rd/rd*10000;
    if (status div 10) = 3 then
    begin
      iht:=round((ph-ULTDrev.VytV.hmin)/ULTDrev.VytV.hdif);
      rh:=ph;
      if iht<ULTDrev.VytV.ihmin then
      begin
        iht:=ULTDrev.VytV.ihmin;
        rh:=ULTDrev.VytV.hmin;
      end;
      if iht>ULTDrev.VytV.ihmax then
      begin
        iht:=ULTDrev.VytV.ihmax;
        rh:=ULTDrev.VytV.hmax;
      end;
      result:=ULTDrev.VytV.v[iht]*pi/4/rh;
    end;
  end;

begin
  result:=0;
  status:=-1;
  idrev:=IndexDrevinyULT(TabDrev);
  if idrev<0 then exit;
  if (d<=0) or (h<=0) then exit;
  status:=0;
  ih1:=floor((h-ULT[idrev].dr_hmin)/ULT[idrev].dr_hdif);
  h1:=ih1 * ULT[idrev].dr_hdif + ULT[idrev].dr_hmin;
  h2:=h1 + ULT[idrev].dr_hdif;
  id1:=floor((d-ULT[idrev].dmin)/ULT[idrev].ddif);
  d1:=id1 * ULT[idrev].ddif + ULT[idrev].dmin;
  d2:=d1+ ULT[idrev].ddif;

  td1h1:=TabVytv(ULT[idrev],d1,h1,status);
  td1h2:=TabVytv(ULT[idrev],d1,h2,status);;
  td2h1:=TabVytv(ULT[idrev],d2,h1,status);;
  td2h2:=TabVytv(ULT[idrev],d2,h2,status);;

  rint:=(d2-d1)*(h2-h1);
  qint:=td1h1*(d2-d)*(h2-h)
       +td1h2*(d2-d)*(h-h1)
       +td2h1*(d-d1)*(h2-h)
       +td2h2*(d-d1)*(h-h1)
        ;
  if rint<>0 then result:=qint/rint;
end;

//initialization
   //nactiTabulky;
end.
